Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5524)

Unified Diff: chrome/browser/ui/website_settings/chooser_bubble_controller.h

Issue 1724183005: Change ChooserBubbleDelegate class name to ChooserBubbleController (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: merged changes from master, resolved conflicts and updated related files Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/website_settings/chooser_bubble_controller.h
diff --git a/chrome/browser/ui/website_settings/chooser_bubble_delegate.h b/chrome/browser/ui/website_settings/chooser_bubble_controller.h
similarity index 82%
rename from chrome/browser/ui/website_settings/chooser_bubble_delegate.h
rename to chrome/browser/ui/website_settings/chooser_bubble_controller.h
index 93afa8928b7fcac1fbb0ec422e7753763c91de74..238b57dba1677e7866fff2f74f4c476e0f96f7ac 100644
--- a/chrome/browser/ui/website_settings/chooser_bubble_delegate.h
+++ b/chrome/browser/ui/website_settings/chooser_bubble_controller.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_WEBSITE_SETTINGS_CHOOSER_BUBBLE_DELEGATE_H_
-#define CHROME_BROWSER_UI_WEBSITE_SETTINGS_CHOOSER_BUBBLE_DELEGATE_H_
+#ifndef CHROME_BROWSER_UI_WEBSITE_SETTINGS_CHOOSER_BUBBLE_CONTROLLER_H_
+#define CHROME_BROWSER_UI_WEBSITE_SETTINGS_CHOOSER_BUBBLE_CONTROLLER_H_
#include <vector>
@@ -14,7 +14,7 @@
class Browser;
class GURL;
// Subclass ChooserBubbleDelegate to implement a chooser bubble, which has
// some introductory text and a list of options that users can pick one of.
// Create an instance of your subclass and pass it to
// BubbleManager::ShowBubble() to show the bubble. Your subclass must define
@@ -24,14 +24,10 @@ class GURL;
// collecting metrics.
// After Select/Cancel/Close is called, this object is destroyed and call back
// into it is not allowed.
-// TODO(juncai): Change class name ChooserBubbleDelegate to
-// ChooserBubbleController since it better reflects its responsibilities and
-// clarifies the roles of this class.
-// https://crbug.com/588933
-class ChooserBubbleDelegate : public BubbleDelegate {
+class ChooserBubbleController : public BubbleDelegate {
public:
- explicit ChooserBubbleDelegate(content::RenderFrameHost* owner);
- ~ChooserBubbleDelegate() override;
+ explicit ChooserBubbleController(content::RenderFrameHost* owner);
+ ~ChooserBubbleController() override;
// Since the set of options can change while the UI is visible an
// implementation should register an observer.
@@ -97,7 +93,7 @@ class ChooserBubbleDelegate : public BubbleDelegate {
const content::RenderFrameHost* const owning_frame_;
Observer* observer_ = nullptr;
- DISALLOW_COPY_AND_ASSIGN(ChooserBubbleDelegate);
+ DISALLOW_COPY_AND_ASSIGN(ChooserBubbleController);
};
-#endif // CHROME_BROWSER_UI_WEBSITE_SETTINGS_CHOOSER_BUBBLE_DELEGATE_H_
+#endif // CHROME_BROWSER_UI_WEBSITE_SETTINGS_CHOOSER_BUBBLE_CONTROLLER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -14,7 +14,7 @@
class Browser;
class GURL;
-// Subclass ChooserBubbleDelegate to implement a chooser bubble, which has
+// Subclass ChooserBubbleController to implement a chooser bubble, which has
// some introductory text and a list of options that users can pick one of.
// Create an instance of your subclass and pass it to